//
//  MVMineProductController.swift
//  MusicVideoPlus
//
//  Created by SanW on 2021/6/22.
//

import BFFramework
import UIKit

class MVMineProductController: PQBaseViewController {
    var itemsList: [PQVideoListModel] = Array<PQVideoListModel>.init()
    var pageNum: Int = 1
    lazy var flowLayout: PQCollectionViewFlowlayout = {
        let flowLayout = PQCollectionViewFlowlayout()
        flowLayout.columnCount = 2
        flowLayout.sectionInset = .zero
        flowLayout.minimumLineSpacing = cDefaultMargin
        flowLayout.minimumInteritemSpacing = cDefaultMargin
        flowLayout.headerH = 0
        return flowLayout
    }()

    lazy var collectionView: UICollectionView = {
        let width = (cScreenWidth - 30) / 2
        let proCollectView = UICollectionView(frame: CGRect(x: cDefaultMargin, y: 0, width: cScreenWidth - cDefaultMargin * 2, height: view.frame.height), collectionViewLayout: flowLayout)
        proCollectView.register(MVMineProductCell.self, forCellWithReuseIdentifier: String(describing: MVMineProductCell.self))
        proCollectView.showsVerticalScrollIndicator = false
        proCollectView.delegate = self
        proCollectView.dataSource = self
        proCollectView.backgroundColor = UIColor.white
        proCollectView.addRefreshView { [weak self] isRefresh in
            self?.loadRequestData(isRefresh: isRefresh)
        }
        return proCollectView
    }()

    override func viewDidLoad() {
        super.viewDidLoad()
        view.addSubview(collectionView)
        leftBackButton()
        loadRequestData()
    }

    /// 请求网络数据
    /// - Parameter isRefresh: <#isRefresh description#>
    /// - Returns: <#description#>
    func loadRequestData(isRefresh: Bool = true) {
        if isRefresh {
            pageNum = 1
        } else {
            pageNum = pageNum + 1
        }
        MVMineViewModel.userVideoListData(pageNum: pageNum) { [weak self] videoList, _ in
            if videoList != nil, (videoList?.count ?? 0) > 0 {
                if isRefresh {
                    self?.itemsList = videoList!
                } else {
                    self?.itemsList = self!.itemsList + videoList!
                }
                self?.flowLayout.findList = self?.itemsList as! [PQVideoListModel]
                self?.collectionView.reloadData()
            } else {
                self?.pageNum = (self?.pageNum ?? 1) - 1
            }
            self?.collectionView.mj_header?.endRefreshing()
            self?.collectionView.mj_footer?.endRefreshing()
        }
    }
}

extension MVMineProductController: UICollectionViewDelegate, UICollectionViewDataSource, UIScrollViewDelegate {
    func collectionView(_: UICollectionView, numberOfItemsInSection _: Int) -> Int {
        return itemsList.count
    }

    func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {
        let itemData = itemsList[indexPath.item]
        let cell = MVMineProductCell.productCell(collectionView: collectionView, indexPath: indexPath)
        cell.videoData = itemData
        cell.btnClickHandle = { [weak self] _, _ in
//            self?.btnClickHandle(sender: sender, videoData: videoData)
        }
        return cell
    }

    func collectionView(_: UICollectionView, didSelectItemAt _: IndexPath) {}
}
